/**
 * Provides a method to get the CPU time
 * of the current thread, when the iXprof
 * library is loaded as profiling agent
 * via -XruniXprof.
 *
 * @author Michael Tamm
 */
public class iXprof {
    private static RuntimeException c_initError = null;
    static {
        try {
            System.loadLibrary("iXprof");
        } catch (RuntimeException e) {
            c_initError = e;
        }
    }

    private iXprof() {}

    /**
     * Returns the CPU time for the current
     * thread in nanoseconds, see iXprof.cpp.
     */
    private static native long getCurrentThreadCpuTime();

    /**
     * Returns the CPU time for the
     * current thread in milliseconds.
     */
    public static long currentThreadTimeMillis() {
        if (c_initError != null) {
            throw c_initError;
        }
        long nanoSeconds = getCurrentThreadCpuTime();
        if (nanoSeconds == -1) {
            throw new RuntimeException("iXprof not registered as profiling agent, you need to start java with the option -XruniXprof.");
        }
        return (nanoSeconds + 500000) / 1000000;
    }
}
